from flask import Flask
from flask_mail import Mail, Message
import os

def hello():
    print("Hello from imhotep_mail!") #a function to be called from the terminale to checks if library is installed or not

def mail_config(smtp_server, smtp_port, username, password, user_tls=True, user_ssl=False):

    app = Flask(__name__) #define the app (teh flask contetxt)

    #defining the mail configuration
    app.config['MAIL_SERVER']= smtp_server
    app.config['MAIL_PORT'] = smtp_port
    app.config['MAIL_USERNAME'] = username
    app.config['MAIL_PASSWORD'] = password
    app.config['MAIL_USE_TLS'] = user_tls
    app.config['MAIL_USE_SSL'] = user_ssl
    app.config['MAIL_DEFAULT_SENDER'] = username
    mail = Mail(app)
    return app, mail

def send_mail(smtp_server, smtp_port, username, password, to_email, subject, body, attachments=None, is_html=False, user_tls=False, user_ssl=True):

    #running the mail config function to run the mail data on a flask context
    app, mail = mail_config(smtp_server, smtp_port, username, password, user_tls, user_ssl)

    #running the function inside flask context
    with app.app_context():
        #sending the mail
        msg = Message(subject=subject, sender=username, recipients=[to_email])
        #the mail body
        msg.body = body
        #if there is an html so the body will run as an html
        msg.html = body if is_html else None

        # Attach files to be sent if teh functin call get it
        if attachments:
            for file_path in attachments:
                if os.path.exists(file_path):
                    try:
                        with open(file_path, 'rb') as fp:
                            msg.attach(
                                filename=os.path.basename(file_path),
                                content_type="application/octet-stream",
                                data=fp.read()
                            )
                    except Exception as e:
                        print(f"Failed to attach file {file_path}: {str(e)}")
                        continue  # Skip this attachment

        try:
            mail.send(msg)
            return "Email sent successfully", None
        except Exception as e:
            return None, f"Failed to send email: {str(e)}"



from setuptools import setup, find_packages

setup(
    name='imhotep_mail',  # Name of your library
    version='0.0.2',  # Version number
    packages=find_packages(),  # Automatically find package directories
    install_requires=[
        'Flask',
        'flask_mail',
    ],
    description='A python library to send mails easily',
    long_description=open('README.md').read(),  # Read long description from README
    long_description_content_type='text/markdown',
    author='Karim Bassem',
    author_email='imhoteptech@outlook.com',
    url='https://github.com/Imhotep-Tech/imhotep_mail',  # URL of your project
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',  # Minimum Python version
    entry_points={
      "console_scripts": [
          "imhotep-mail = imhotep_mail:hello",
      ],
  },
)
